@@ -29,23 +29,7 @@ class KnockPY(object):
     async def bufferover_run(self):
         """@return List"""
         try:            
-            url = "https://dns.bufferover.run/dns?q={domain}".format(domain=self.domain)
-            resp = {} 
-            subdomains = []
-            
-            async with httpx.AsyncClient() as client:
-                req = await client.get(url, timeout=self.timeout)
-                resp = req.json()
-                
-            FDNS_A = req.json().get("FDNS_A")
-            for fdns in FDNS_A:
-                if("," in fdns):
-                    sub = fdns.split(",")[-1]
-                    subdomains.append(sub)
-                else:
-                    subdomains.append(fdns)
-            return list(set(subdomains))
-            
+            return []
         except Exception as e:
             print("[Knockpy bufferover_run ERROR]", e, flush=True)
             return []
@@ -117,8 +101,28 @@ class KnockPY(object):
     async def projectdiscovery(self):
         """@return List"""
         try:
+            if not self.discoveryapi:
+                return [] 
+                
+            headers = {"Authorization":self.discoveryapi}
+            url="https://dns.projectdiscovery.io/dns/{domain}/subdomains".format(domain=self.domain)
+            resp = None
             
-            return []
+            async with httpx.AsyncClient() as client:
+                resp = await client.get(url, headers=headers, timeout=self.timeout)
+                
+            subdomains = []
+            
+            if(resp is not None):
+                if(resp.status_code == 200):
+                    data = resp.json()
+                    subdomain_data = data.get("subdomains")
+                    subdomain_domain = data.get("domain")
+                    
+                    for subs in subdomain_data:
+                        subdomains.append(subs+"."+subdomain_domain)
+                    return subdomains
+            return subdomains
         except Exception as e:
             print("[Knockpy projectdiscovery ERROR]", e, flush=True)
             return []
